@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "trailing-newline-indicator" "0.3.6"
+(define-package "trailing-newline-indicator" "20251115.2242"
   "Show an indicator for the trailing newline."
   '((emacs "26.1"))
   :url "https://github.com/saulotoledo/trailing-newline-indicator"
-  :commit "f53d9e139f734d9ea35a907a6c44b70795d81737"
-  :revdesc "f53d9e139f73"
+  :commit "9d4d8cba8ae20301458b9f9a4399c72951c70471"
+  :revdesc "9d4d8cba8ae2"
   :keywords '("convenience" "display" "editing")
   :authors '(("Saulo S. de Toledo" . "saulotoledo@gmail.com"))
   :maintainers '(("Saulo S. de Toledo" . "saulotoledo@gmail.com")))
